RealFileSystem

Struct RealFileSystem 

pub struct RealFileSystem;
Reads and writes the actual filesystem. Stateless, so it is cheap to share across the worker thread and any future services that need it.

Implementations

Source

impl RealFileSystem

pub const fn new() -> Self